"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useSiteEditorNavigationCommands = useSiteEditorNavigationCommands;

var _commands = require("@wordpress/commands");

var _i18n = require("@wordpress/i18n");

var _element = require("@wordpress/element");

var _data = require("@wordpress/data");

var _coreData = require("@wordpress/core-data");

var _icons = require("@wordpress/icons");

var _router = require("@wordpress/router");

var _url = require("@wordpress/url");

var _lockUnlock = require("./lock-unlock");

/**
 * WordPress dependencies
 */

/**
 * Internal dependencies
 */
const {
  useHistory
} = (0, _lockUnlock.unlock)(_router.privateApis);
const icons = {
  post: _icons.post,
  page: _icons.page,
  wp_template: _icons.layout,
  wp_template_part: _icons.symbolFilled
};

const getNavigationCommandLoaderPerPostType = postType => function useNavigationCommandLoader({
  search
}) {
  const history = useHistory();
  const supportsSearch = !['wp_template', 'wp_template_part'].includes(postType);
  const {
    records,
    isLoading
  } = (0, _data.useSelect)(select => {
    const {
      getEntityRecords
    } = select(_coreData.store);
    const query = supportsSearch ? {
      search: !!search ? search : undefined,
      per_page: 10,
      orderby: search ? 'relevance' : 'date',
      status: ['publish', 'future', 'draft', 'pending', 'private']
    } : {
      per_page: -1
    };
    return {
      records: getEntityRecords('postType', postType, query),
      isLoading: !select(_coreData.store).hasFinishedResolution('getEntityRecords', ['postType', postType, query])
    };
  }, [supportsSearch, search]);
  const commands = (0, _element.useMemo)(() => {
    return (records !== null && records !== void 0 ? records : []).slice(0, 10).map(record => {
      const isSiteEditor = (0, _url.getPath)(window.location.href)?.includes('site-editor.php');
      const extraArgs = isSiteEditor ? {
        canvas: (0, _url.getQueryArg)(window.location.href, 'canvas')
      } : {};
      return {
        name: postType + '-' + record.id,
        searchLabel: record.title?.rendered + ' ' + record.id,
        label: record.title?.rendered ? record.title?.rendered : (0, _i18n.__)('(no title)'),
        icon: icons[postType],
        callback: ({
          close
        }) => {
          const args = {
            postType,
            postId: record.id,
            ...extraArgs
          };
          const targetUrl = (0, _url.addQueryArgs)('site-editor.php', args);

          if (isSiteEditor) {
            history.push(args);
          } else {
            document.location = targetUrl;
          }

          close();
        }
      };
    });
  }, [records, history]);
  return {
    commands,
    isLoading
  };
};

const usePageNavigationCommandLoader = getNavigationCommandLoaderPerPostType('page');
const usePostNavigationCommandLoader = getNavigationCommandLoaderPerPostType('post');
const useTemplateNavigationCommandLoader = getNavigationCommandLoaderPerPostType('wp_template');
const useTemplatePartNavigationCommandLoader = getNavigationCommandLoaderPerPostType('wp_template_part');

function useSiteEditorBasicNavigationCommands() {
  const history = useHistory();
  const isSiteEditor = (0, _url.getPath)(window.location.href)?.includes('site-editor.php');
  const commands = (0, _element.useMemo)(() => {
    const result = [];
    result.push({
      name: 'core/edit-site/open-navigation',
      label: (0, _i18n.__)('Open navigation'),
      icon: _icons.navigation,
      callback: ({
        close
      }) => {
        const args = {
          path: '/navigation'
        };
        const targetUrl = (0, _url.addQueryArgs)('site-editor.php', args);

        if (isSiteEditor) {
          history.push(args);
        } else {
          document.location = targetUrl;
        }

        close();
      }
    });
    result.push({
      name: 'core/edit-site/open-pages',
      label: (0, _i18n.__)('Open pages'),
      icon: _icons.page,
      callback: ({
        close
      }) => {
        const args = {
          path: '/page'
        };
        const targetUrl = (0, _url.addQueryArgs)('site-editor.php', args);

        if (isSiteEditor) {
          history.push(args);
        } else {
          document.location = targetUrl;
        }

        close();
      }
    });
    result.push({
      name: 'core/edit-site/open-style-variations',
      label: (0, _i18n.__)('Open style variations'),
      icon: _icons.styles,
      callback: ({
        close
      }) => {
        const args = {
          path: '/wp_global_styles'
        };
        const targetUrl = (0, _url.addQueryArgs)('site-editor.php', args);

        if (isSiteEditor) {
          history.push(args);
        } else {
          document.location = targetUrl;
        }

        close();
      }
    });
    result.push({
      name: 'core/edit-site/open-templates',
      label: (0, _i18n.__)('Open templates'),
      icon: _icons.layout,
      callback: ({
        close
      }) => {
        const args = {
          path: '/wp_template'
        };
        const targetUrl = (0, _url.addQueryArgs)('site-editor.php', args);

        if (isSiteEditor) {
          history.push(args);
        } else {
          document.location = targetUrl;
        }

        close();
      }
    });
    result.push({
      name: 'core/edit-site/open-template-parts',
      label: (0, _i18n.__)('Open library'),
      icon: _icons.symbolFilled,
      callback: ({
        close
      }) => {
        const args = {
          path: '/patterns'
        };
        const targetUrl = (0, _url.addQueryArgs)('site-editor.php', args);

        if (isSiteEditor) {
          history.push(args);
        } else {
          document.location = targetUrl;
        }

        close();
      }
    });
    return result;
  }, [history, isSiteEditor]);
  return {
    commands,
    isLoading: false
  };
}

function useSiteEditorNavigationCommands() {
  (0, _commands.useCommandLoader)({
    name: 'core/edit-site/navigate-pages',
    hook: usePageNavigationCommandLoader
  });
  (0, _commands.useCommandLoader)({
    name: 'core/edit-site/navigate-posts',
    hook: usePostNavigationCommandLoader
  });
  (0, _commands.useCommandLoader)({
    name: 'core/edit-site/navigate-templates',
    hook: useTemplateNavigationCommandLoader
  });
  (0, _commands.useCommandLoader)({
    name: 'core/edit-site/navigate-template-parts',
    hook: useTemplatePartNavigationCommandLoader
  });
  (0, _commands.useCommandLoader)({
    name: 'core/edit-site/basic-navigation',
    hook: useSiteEditorBasicNavigationCommands,
    context: 'site-editor'
  });
}
//# sourceMappingURL=site-editor-navigation-commands.js.map